@@ -15,11 +15,11 @@
 
 import collections
 import errno
+from functools import wraps
 import hashlib
 import json
 import os
 import requests
-import six
 import shutil
 
 from oslo_log import log as logging
@@ -54,7 +54,7 @@ TYPE_MAP_EXTENSION = '.type-map'
 
 
 def skip_if_exists(f):
-    @six.wraps(f)
+    @wraps(f)
     def wrapper(*args, **kwargs):
         try:
             return f(*args, **kwargs)
@@ -261,17 +261,11 @@ def export_manifest_config(target_url,
 
     manifests_path = os.path.join(
         IMAGE_EXPORT_DIR, 'v2', image, 'manifests')
-    manifests_htaccess_path = os.path.join(manifests_path, '.htaccess')
     manifest_dir_path = os.path.join(manifests_path, manifest_digest)
     manifest_path = os.path.join(manifest_dir_path, 'index.json')
     htaccess_path = os.path.join(manifest_dir_path, '.htaccess')
 
     make_dir(manifest_dir_path)
-    build_catalog()
-
-    with open(manifests_htaccess_path, 'w+') as f:
-        f.write('AddHandler type-map %s\n' % TYPE_MAP_EXTENSION)
-        f.write('MultiviewsMatch Handlers\n')
 
     headers = collections.OrderedDict()
     headers['Content-Type'] = manifest_type
@@ -310,6 +304,7 @@ def export_manifest_config(target_url,
     if manifest_dict:
         write_type_map_file(image, tag, manifest_dict)
     build_tags_list(image)
+    build_catalog()
 
 
 def write_type_map_file(image, tag, manifest_dict):
