@@ -15,7 +15,7 @@
 
 import json
 import os
-from six.moves import configparser
+import configparser
 import shutil
 import tempfile
 from unittest import mock
